@@ -174,7 +174,7 @@ class TinyTextEntity
                                             : QString::fromRawData( d.data, length );
         }
 
-        inline NormalizedRect transformedArea( const QMatrix &matrix ) const
+        inline NormalizedRect transformedArea( const QTransform &matrix ) const
         {
             NormalizedRect transformed_area = area;
             transformed_area.transform( matrix );
@@ -215,7 +215,7 @@ NormalizedRect* TextEntity::area() const
     return m_area;
 }
 
-NormalizedRect TextEntity::transformedArea(const QMatrix &matrix) const
+NormalizedRect TextEntity::transformedArea(const QTransform &matrix) const
 {
     NormalizedRect transformed_area = *m_area;
     transformed_area.transform( matrix );
@@ -359,7 +359,7 @@ RegularAreaRect * TextPage::textArea ( TextSelection * sel) const
 */
     RegularAreaRect * ret= new RegularAreaRect;
 
-    const QMatrix matrix = d->m_page ? d->m_page->rotationMatrix() : QMatrix();
+    const QTransform matrix = d->m_page ? d->m_page->rotationMatrix() : QTransform();
 #if 0
     int it = -1;
     int itB = -1;
@@ -840,7 +840,7 @@ RegularAreaRect* TextPagePrivate::findTextInternalForward( int searchID, const Q
                                                              const TextList::ConstIterator &start,
                                                              const TextList::ConstIterator &end )
 {
-    const QMatrix matrix = m_page ? m_page->rotationMatrix() : QMatrix();
+    const QTransform matrix = m_page ? m_page->rotationMatrix() : QTransform();
 
     RegularAreaRect* ret=new RegularAreaRect;
 
@@ -955,7 +955,7 @@ RegularAreaRect* TextPagePrivate::findTextInternalBackward( int searchID, const
                                                             const TextList::ConstIterator &start,
                                                             const TextList::ConstIterator &loop_end )
 {
-    const QMatrix matrix = m_page ? m_page->rotationMatrix() : QMatrix();
+    const QTransform matrix = m_page ? m_page->rotationMatrix() : QTransform();
 
     RegularAreaRect* ret=new RegularAreaRect;
 
@@ -981,6 +981,16 @@ RegularAreaRect* TextPagePrivate::findTextInternalBackward( int searchID, const
         {
             offsetMoved = true;
         }
+        if ( query.at(j).isSpace() )
+        {
+            // lets match newline as a space
+#ifdef DEBUG_TEXTPAGE
+            kDebug(OkularDebug) << "newline or space";
+#endif
+            j--;
+            queryLeft--;
+        }
+        else
         {
             len = stringLengthAdaptedWithHyphen(str, it, m_words.constEnd(), m_page);
             int min=qMin(queryLeft,len);
