@@ -42,6 +42,11 @@
 #include <ktoggleaction.h>
 #include <ktogglefullscreenaction.h>
 #include <kactioncollection.h>
+#include <kwindowsystem.h>
+
+#ifdef KActivities_FOUND
+#include <KActivities/ResourceInstance>
+#endif
 
 // local includes
 #include "kdocumentviewer.h"
@@ -52,6 +57,9 @@ static const char *shouldShowToolBarComingFromFullScreen = "shouldShowToolBarCom
 
 Shell::Shell(KCmdLineArgs* args, int argIndex)
   : KParts::MainWindow(), m_args(args), m_menuBarWasShown(true), m_toolBarWasShown(true)
+#ifdef KActivities_FOUND
+    , m_activityResource(0)
+#endif
 {
   if (m_args && argIndex != -1)
   {
@@ -95,18 +103,26 @@ void Shell::init()
     setupGUI(Keys | ToolBar | Save);
     createGUI(m_part);
     m_doc = qobject_cast<KDocumentViewer*>(m_part);
-    
     connect( this, SIGNAL(restoreDocument(KConfigGroup)),m_part, SLOT(restoreDocument(KConfigGroup)));
     connect( this, SIGNAL(saveDocumentRestoreInfo(KConfigGroup&)), m_part, SLOT(saveDocumentRestoreInfo(KConfigGroup&)));
     connect( m_part, SIGNAL(enablePrintAction(bool)), m_printAction, SLOT(setEnabled(bool)));
-    
-    readSettings();
+    connect( m_part, SIGNAL(enableCloseAction(bool)), m_closeAction, SLOT(setEnabled(bool)));
 
     if (m_args && m_args->isSet("unique") && m_args->count() == 1)
     {
         QDBusConnection::sessionBus().registerService("org.kde.okular");
     }
 
+    m_unique = false;
+    if (m_args && m_args->isSet("unique") && m_args->count() <= 1)
+    {
+        m_unique = QDBusConnection::sessionBus().registerService("org.kde.okular");
+        if (!m_unique)
+            KMessageBox::information(this, i18n("There is already a unique Okular instance running. This instance won't be the unique one."));
+    }
+    
+    QDBusConnection::sessionBus().registerObject("/okularshell", this, QDBusConnection::ExportScriptableSlots);
+
     if (m_openUrl.isValid()) QTimer::singleShot(0, this, SLOT(delayedOpen()));
   }
   else
@@ -120,6 +136,11 @@ void Shell::delayedOpen()
    openUrl( m_openUrl );
 }
 
+void Shell::showOpenRecentMenu()
+{
+    m_recent->menu()->popup(QCursor::pos());
+}
+
 Shell::~Shell()
 {
     if ( m_part )
@@ -136,20 +157,48 @@ void Shell::openUrl( const KUrl & url )
 {
     if ( m_part )
     {
-        if ( m_doc && m_args && m_args->isSet( "presentation" ) )
-            m_doc->startPresentation();
-        bool openOk = m_part->openUrl( url );
-        const bool isstdin = url.fileName( KUrl::ObeyTrailingSlash ) == QLatin1String( "-" );
-        if ( !isstdin )
+        if( !m_part->url().isEmpty() )
         {
-            if ( openOk )
-                m_recent->addUrl( url );
+            if( m_unique )
+            {
+                KMessageBox::error(this, i18n("Can't open more than one document in the unique Okular instance."));
+            }
             else
-                m_recent->removeUrl( url );
+            {
+                Shell* newShell = new Shell();
+                newShell->openUrl( url );
+                newShell->show();
+            }
+        }
+        else
+        {
+            if ( m_doc && m_args && m_args->isSet( "presentation" ) )
+                m_doc->startPresentation();
+            bool openOk = m_part->openUrl( url );
+            const bool isstdin = url.fileName( KUrl::ObeyTrailingSlash ) == QLatin1String( "-" );
+            if ( !isstdin )
+            {
+                if ( openOk )
+                {
+#ifdef KActivities_FOUND
+                    if ( !m_activityResource )
+                        m_activityResource = new KActivities::ResourceInstance( window()->winId(), this );
+
+                    m_activityResource->setUri( url );
+#endif
+                    m_recent->addUrl( url );
+                }
+                else
+                    m_recent->removeUrl( url );
+            }
         }
     }
 }
 
+void Shell::closeUrl()
+{
+    m_part->closeUrl();
+}
 
 void Shell::readSettings()
 {
@@ -185,12 +234,13 @@ void Shell::setupActions()
   KStandardAction::open(this, SLOT(fileOpen()), actionCollection());
   m_recent = KStandardAction::openRecent( this, SLOT(openUrl(KUrl)), actionCollection() );
   m_recent->setToolBarMode( KRecentFilesAction::MenuMode );
-  m_recent->setToolButtonPopupMode( QToolButton::DelayedPopup );
-  connect( m_recent, SIGNAL(triggered()), this, SLOT(fileOpen()) );
+  connect( m_recent, SIGNAL(triggered()), this, SLOT(showOpenRecentMenu()) );
   m_recent->setToolTip( i18n("Click to open a file\nClick and hold to open a recent file") );
   m_recent->setWhatsThis( i18n( "<b>Click</b> to open a file or <b>Click and hold</b> to select a recent file" ) );
   m_printAction = KStandardAction::print( m_part, SLOT(slotPrint()), actionCollection() );
   m_printAction->setEnabled( false );
+  m_closeAction = KStandardAction::close( this, SLOT(closeUrl()), actionCollection() );
+  m_closeAction->setEnabled( false );
   KStandardAction::quit(this, SLOT(slotQuit()), actionCollection());
 
   setStandardToolBarMenuEnabled(true);
@@ -241,10 +291,6 @@ QStringList Shell::fileFormats() const
 
 void Shell::fileOpen()
 {
-    // Don't open dialog if current document can't be closed
-    if ( !m_part->queryClose() )
-        return;
-
 	// this slot is called whenever the File->Open menu is selected,
 	// the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
 	// button is clicked
@@ -279,7 +325,6 @@ void Shell::fileOpen()
     KUrl url = dlg.selectedUrl();
     if ( !url.isEmpty() )
     {
-        m_part->closeUrl( false );
         openUrl( url );
     }
 }
@@ -289,6 +334,14 @@ void Shell::slotQuit()
     close();
 }
 
+void Shell::tryRaise()
+{
+    if (m_unique)
+    {
+        KWindowSystem::forceActiveWindow( window()->effectiveWinId() );
+    }
+}
+
 // only called when starting the program
 void Shell::setFullScreen( bool useFullScreen )
 {
